@@ -41,13 +41,13 @@
  *****************************************************************************/
 
 /* Program version and copyright message */
-#define VERSION_MESSAGE     "vlc 0.2.60 Urumov " \
+#define VERSION_MESSAGE     "vlc 0.2.61 Urumov " \
                           /* "(" PROGRAM_BUILD ") (" PROGRAM_OPTIONS ")\n" */ \
                             "Copyright 1996-2000 VideoLAN\n"
-#define COPYRIGHT_MESSAGE   "VideoLAN Client - version 0.2.60" \
+#define COPYRIGHT_MESSAGE   "VideoLAN Client - version 0.2.61" \
                             " Urumov - (c)1996-2000 VideoLAN\n"
 
-#define VERSION             "0.2.60"
+#define VERSION             "0.2.61"
 
 /*****************************************************************************
  * General compilation options
@@ -149,13 +149,6 @@
 /* Maximum number of channels */
 #define INTF_MAX_CHANNELS               10
 
-/*
- * X11 settings
- */
-
-/* Title of the X11 window */
-#define VOUT_TITLE                      "VideoLAN Client"
-
 /*****************************************************************************
  * Input thread configuration
  *****************************************************************************/
@@ -381,7 +374,8 @@
  * FB_NOYPAN
  */
 // #define FB_NOYPAN
-   
+
+#define VOUT_TITLE                      "VideoLAN Client 0.2.61"
 
 /*****************************************************************************
  * Video parser configuration
